API: support modules
>>>>>>>>>>>>>>>>>>>>

Frequency tracking
<<<<<<<<<<<<<<<<<<
.. automodule:: itsfm.frequency_tracking
   :members:
   
Signal processing 
<<<<<<<<<<<<<<<<<
Functions which actually do the calculations on the raw input signal 

.. automodule:: itsfm.signal_processing
   :members:


Signal cleaning
<<<<<<<<<<<<<<<
Functions which refine, clean and detect outliers.

.. automodule:: itsfm.signal_cleaning
   :members:
   
Batch processing
<<<<<<<<<<<<<<<<
.. automodule:: itsfm.batch_processing
   :members: